@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -18,18 +18,38 @@ has meta => (is=>'rw');
 has name => (is=>'rw');
 has url  => (is=>'rw');
 has _pa => (is=>'rw');
+has parent => (is=>'rw'); # points fo Perinci::To::* object
 
 sub BUILD {
     my ($self, $args) = @_;
 
     $args->{meta} or die "Please specify meta";
 
+    my $pdres = $self->{parent}{_doc_res};
+
+    if (@{ $pdres->{function_names_by_meta_addr}{"$args->{meta}"} } > 1) {
+        # function is an alias to another function, no need to duplicate
+        # documenting the function, just mention that this function is alias to
+        # another.
+        $self->{doc_sections} //= [
+            # actually not needed but gen_doc_section_summary() et al currently
+            # sets dres->{name}, dres->{summary}, etc. this will be refactored
+            # later, gen_doc_section_summary() et al should've just add doc
+            # lines.
+            'summary',
+            'arguments',
+            'result',
+
+            'alias',
+        ];
+    }
+
     $self->{doc_sections} //= [
         'summary',
+        'synopsis',
         'description',
         'arguments',
         'result',
-        'examples',
         'links',
     ];
     $self->{_pa} = do {
@@ -42,6 +62,7 @@ sub before_gen_doc {
     my ($self, %opts) = @_;
     $log->tracef("=> FuncBase's before_gen_doc(opts=%s)", \%opts);
 
+    $self->{_orig_meta} = $self->{meta};
     $self->{meta} = normalize_function_metadata($self->{meta});
 
     # initialize hash to store [intermediate] result
@@ -66,6 +87,10 @@ sub add_doc_lines {
         map {"$indent$_"} @lines;
 }
 
+sub gen_doc_section_alias {
+    # currently in after_gen_doc()
+}
+
 sub gen_doc_section_summary {
     my ($self) = @_;
 
@@ -80,6 +105,10 @@ sub gen_doc_section_summary {
     $dres->{summary} = $summary;
 }
 
+sub gen_doc_section_synopsis {
+    # currently in after_gen_doc()
+}
+
 sub gen_doc_section_description {
     my ($self) = @_;
 
@@ -174,10 +203,6 @@ sub gen_doc_section_result {
     $dres->{res_description} = $riresmeta->langprop("description");
 }
 
-sub gen_doc_section_examples {
-    # not yet
-}
-
 sub gen_doc_section_links {
     # not yet
 }
@@ -197,7 +222,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.66 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-09-25.
+This document describes version 0.67 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-09-26.
 
 =for Pod::Coverage .+
 
