@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -42,6 +42,18 @@ sub after_gen_doc {
             ($has_args ? $dres->{args_plterm} : "()").' -> '.$dres->{human_ret},
         "");
 
+    {
+        my $pdres = $self->parent->{_doc_res};
+        my $fnames = $pdres->{function_names_by_meta_addr}{"$self->{_orig_meta}"};
+        if (@$fnames > 1) {
+            $self->add_doc_lines(
+                __("Alias for") . " C<$fnames->[0]>.",
+                "",
+            );
+            return;
+        }
+    }
+
     $self->add_doc_lines(
         $dres->{summary}.($dres->{summary} =~ /\.$/ ? "":"."), "")
         if $dres->{summary};
@@ -333,7 +345,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.66 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-25.
+This document describes version 0.67 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-09-26.
 
 =head1 SYNOPSIS
 
