@@ -1,7 +1,7 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
@@ -99,12 +99,19 @@ sub gen_doc_section_functions {
 
     # generate doc for all functions
     $dres->{functions} = {};
+    $dres->{function_names_by_meta_addr} = {};
     for my $furi (@func_uris) {
         my $fname = $furi; $fname =~ s!.+/!!;
         my $meta = $cmetas->{$furi};
         next if $meta->{'x.no_index'};
+        push @{ $dres->{function_names_by_meta_addr}{"$meta"} }, $fname;
         $dres->{functions}{$furi} =
-            $self->_gen_func_doc(name=>$fname, meta=>$meta, url=>"$self->{url}$furi");
+            $self->_gen_func_doc(
+                parent=>$self,
+                name=>$fname,
+                meta=>$meta,
+                url=>"$self->{url}$furi",
+            );
     }
 }
 
@@ -126,7 +133,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.66 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-09-25.
+This document describes version 0.67 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-09-26.
 
 =for Pod::Coverage .+
 
